# WafRuleAttributes


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**modsec_rule_id** | **int** | Corresponding ModSecurity rule ID. | [optional] [readonly] 
**publisher** | **str** | Rule publisher. | [optional] [readonly] 
**type** | **str** | The rule&#39;s [type](https://docs.fastly.com/en/guides/managing-rules-on-the-fastly-waf#understanding-the-types-of-rules). | [optional] [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


